==> openshift-model-operatorhub-5.8.1-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/SubscriptionStatusBuilder.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class SubscriptionStatusBuilder extends io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluentImpl<io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatus,io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusBuilder>{
  public SubscriptionStatusBuilder() {
    this(false);
  }
  public SubscriptionStatusBuilder(java.lang.Boolean validationEnabled) {
    this(new SubscriptionStatus(), validationEnabled);
  }
  public SubscriptionStatusBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public SubscriptionStatusBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new SubscriptionStatus(), validationEnabled);
  }
  public SubscriptionStatusBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatus instance) {
    this(fluent, instance, false);
  }
  public SubscriptionStatusBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withCatalogHealth(instance.getCatalogHealth()); 
    fluent.withConditions(instance.getConditions()); 
    fluent.withCurrentCSV(instance.getCurrentCSV()); 
    fluent.withInstallPlanGeneration(instance.getInstallPlanGeneration()); 
    fluent.withInstallPlanRef(instance.getInstallPlanRef()); 
    fluent.withInstalledCSV(instance.getInstalledCSV()); 
    fluent.withInstallplan(instance.getInstallplan()); 
    fluent.withLastUpdated(instance.getLastUpdated()); 
    fluent.withReason(instance.getReason()); 
    fluent.withState(instance.getState()); 
    this.validationEnabled = validationEnabled; 
  }
  public SubscriptionStatusBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatus instance) {
    this(instance,false);
  }
  public SubscriptionStatusBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withCatalogHealth(instance.getCatalogHealth()); 
    this.withConditions(instance.getConditions()); 
    this.withCurrentCSV(instance.getCurrentCSV()); 
    this.withInstallPlanGeneration(instance.getInstallPlanGeneration()); 
    this.withInstallPlanRef(instance.getInstallPlanRef()); 
    this.withInstalledCSV(instance.getInstalledCSV()); 
    this.withInstallplan(instance.getInstallplan()); 
    this.withLastUpdated(instance.getLastUpdated()); 
    this.withReason(instance.getReason()); 
    this.withState(instance.getState()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatus build() {
    SubscriptionStatus buildable = new SubscriptionStatus(fluent.getCatalogHealth(),fluent.getConditions(),fluent.getCurrentCSV(),fluent.getInstallPlanGeneration(),fluent.getInstallPlanRef(),fluent.getInstalledCSV(),fluent.getInstallplan(),fluent.getLastUpdated(),fluent.getReason(),fluent.getState());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SubscriptionStatusBuilder that = (SubscriptionStatusBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-operatorhub-5.12.0-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/SubscriptionStatusBuilder.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class SubscriptionStatusBuilder extends io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluentImpl<io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatus,io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusBuilder>{
  public SubscriptionStatusBuilder() {
    this(false);
  }
  public SubscriptionStatusBuilder(java.lang.Boolean validationEnabled) {
    this(new SubscriptionStatus(), validationEnabled);
  }
  public SubscriptionStatusBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public SubscriptionStatusBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new SubscriptionStatus(), validationEnabled);
  }
  public SubscriptionStatusBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatus instance) {
    this(fluent, instance, false);
  }
  public SubscriptionStatusBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent<?> fluent,io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withCatalogHealth(instance.getCatalogHealth()); 
    fluent.withConditions(instance.getConditions()); 
    fluent.withCurrentCSV(instance.getCurrentCSV()); 
    fluent.withInstallPlanGeneration(instance.getInstallPlanGeneration()); 
    fluent.withInstallPlanRef(instance.getInstallPlanRef()); 
    fluent.withInstalledCSV(instance.getInstalledCSV()); 
    fluent.withInstallplan(instance.getInstallplan()); 
    fluent.withLastUpdated(instance.getLastUpdated()); 
    fluent.withReason(instance.getReason()); 
    fluent.withState(instance.getState()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public SubscriptionStatusBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatus instance) {
    this(instance,false);
  }
  public SubscriptionStatusBuilder(io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withCatalogHealth(instance.getCatalogHealth()); 
    this.withConditions(instance.getConditions()); 
    this.withCurrentCSV(instance.getCurrentCSV()); 
    this.withInstallPlanGeneration(instance.getInstallPlanGeneration()); 
    this.withInstallPlanRef(instance.getInstallPlanRef()); 
    this.withInstalledCSV(instance.getInstalledCSV()); 
    this.withInstallplan(instance.getInstallplan()); 
    this.withLastUpdated(instance.getLastUpdated()); 
    this.withReason(instance.getReason()); 
    this.withState(instance.getState()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatusFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operatorhub.v1alpha1.SubscriptionStatus build() {
    SubscriptionStatus buildable = new SubscriptionStatus(fluent.getCatalogHealth(),fluent.getConditions(),fluent.getCurrentCSV(),fluent.getInstallPlanGeneration(),fluent.getInstallPlanRef(),fluent.getInstalledCSV(),fluent.getInstallplan(),fluent.getLastUpdated(),fluent.getReason(),fluent.getState());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SubscriptionStatusBuilder that = (SubscriptionStatusBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
